@@ -2,33 +2,24 @@
 #'
 #' Run the Jackknife test for variable importance removing one variable at time.
 #'
-#' @param model \code{\linkS4class{SDMmodel}} or \code{\linkS4class{SDMmodelCV}}
-#' object.
+#' @param model \linkS4class{SDMmodel} or \linkS4class{SDMmodelCV} object.
 #' @param metric character. The metric used to evaluate the models, possible
 #' values are: "auc", "tss" and "aicc".
 #' @param variables vector. Variables used for the test, if not provided it
-#' takes all the variables used to train the model, default is \code{NULL}.
-#' @param test \code{\linkS4class{SWD}}. If provided it reports the result also
-#' for the test dataset. Not used for **aicc** and
-#' \code{\linkS4class{SDMmodelCV}}.
-#' @param with_only logical. If \code{TRUE} it runs the test also for each
-#' variable in isolation, default is \code{TRUE}.
-#' @param env \code{\link[raster]{stack}} containing the environmental
-#' variables, used only with "aicc", default is \code{NULL}.
-#' @param parallel logical, if \code{TRUE} it uses parallel computation, default
-#' is \code{FALSE}. Used only with \code{metric = "aicc"}, see details.
-#' @param return_models logical, if \code{TRUE} returns all the models together
-#' with the test result, default is \code{FALSE}.
+#' takes all the variables used to train the model, default is `NULL`.
+#' @param test \linkS4class{SWD}. If provided it reports the result also for the
+#' testing dataset. Not used for **aicc** and \linkS4class{SDMmodelCV}.
+#' @param with_only logical. If `TRUE` it runs the test also for each
+#' variable in isolation, default is `TRUE`.
+#' @param env \link[raster]{stack} containing the environmental variables, used
+#' only with "aicc", default is `NULL`.
+#' @param parallel deprecated.
+#' @param return_models logical, if `TRUE` returns all the models together with
+#' the test result, default is `FALSE`.
 #'
-#' @details Parallel computation is used only during the execution of the
-#' predict function, and increases the speed only for large datasets. For small
-#' dataset it may result in a longer execution, due to the time necessary to
-#' create the cluster.
-#'
-#' @return A data frame with the test results. If "\code{return_model = TRUE}"
-#' it returns a list containing the test results together with the models.
+#' @return A data frame with the test results. If `return_model = TRUE` it
+#' returns a list containing the test results together with the models.
 #' @export
-#' @importFrom progress progress_bar
 #'
 #' @author Sergio Vignali
 #'
@@ -81,6 +72,11 @@
 doJk <- function(model, metric, variables = NULL, test = NULL, with_only = TRUE,
                  env = NULL, parallel = FALSE, return_models = FALSE) {
 
+  # TODO remove this code in a next release
+  if (parallel)
+    warning("parallel argument is deprecated and not used anymore",
+            call. = FALSE, immediate. = TRUE)
+
   metric <- match.arg(metric, c("auc", "tss", "aicc"))
 
   .check_args(model, metric = metric, test = test, env = env)
@@ -133,7 +129,7 @@ doJk <- function(model, metric, variables = NULL, test = NULL, with_only = TRUE,
 
     jk_model <- .create_model_from_settings(model, settings)
 
-    res[i, 2] <- .get_metric(metric, jk_model, env = env, parallel = parallel)
+    res[i, 2] <- .get_metric(metric, jk_model, env = env)
     if (metric != "aicc")
       res[i, 4] <- .get_metric(metric, jk_model, test = t)
 
@@ -153,7 +149,7 @@ doJk <- function(model, metric, variables = NULL, test = NULL, with_only = TRUE,
 
       jk_model <- .create_model_from_settings(model, settings)
 
-      res[i, 3] <- .get_metric(metric, jk_model, env = env, parallel = parallel)
+      res[i, 3] <- .get_metric(metric, jk_model, env = env)
       if (metric != "aicc")
         res[i, 5] <- .get_metric(metric, jk_model, test = t)
 
