@@ -3,40 +3,32 @@
 #' Given a set of possible hyperparameter values, the function trains models
 #' with all the possible combinations of hyperparameters.
 #'
-#' @param model \code{\linkS4class{SDMmodel}} or code{\linkS4class{SDMmodelCV}}
-#' object.
+#' @param model \linkS4class{SDMmodel} or \linkS4class{SDMmodelCV} object.
 #' @param hypers named list containing the values of the hyperparameters that
 #' should be tuned, see details.
 #' @param metric character. The metric used to evaluate the models, possible
 #' values are: "auc", "tss" and "aicc".
-#' @param test code{\linkS4class{SWD}} object. Test dataset used to evaluate the
-#' model, not used with \code{\link{aicc}} and code{\linkS4class{SDMmodelCV}}
-#' objects, default is \code{NULL}.
-#' @param env \code{\link[raster]{stack}} containing the environmental
-#' variables, used only with "aicc", default is \code{NULL}.
-#' @param parallel logical, if \code{TRUE} it uses parallel computation, default
-#' is \code{FALSE}. Used only with \code{metric = "aicc"}, see details.
-#' @param save_models logical, if \code{FALSE} the models are not saved and the
+#' @param test \linkS4class{SWD} object. Testing dataset used to evaluate the
+#' model, not used with \link{aicc} and \linkS4class{SDMmodelCV} objects,
+#' default is `NULL`.
+#' @param env \link[raster]{stack} containing the environmental variables, used
+#' only with "aicc", default is `NULL`.
+#' @param parallel deprecated.
+#' @param save_models logical, if `FALSE` the models are not saved and the
 #' output contains only a data frame with the metric values for each
-#' hyperparameter combination. Default is \code{TRUE}, set it to \code{FALSE}
-#' when there are many combinations to avoid R crashing for memory overload.
+#' hyperparameter combination. Default is `TRUE`, set it to `FALSE` when there
+#' are many combinations to avoid R crashing for memory overload.
 #'
 #' @details * To know which hyperparameters can be tuned you can use the output
-#' of the function \code{\link{get_tunable_args}}. Hyperparameters not included
-#' in the \code{hypers} argument take the value that they have in the passed
-#' model.
-#' * Parallel computation is used only during the execution of the predict
-#' function, and increases the speed only for large datasets. For small dataset
-#' it may result in a longer execution, due to the time necessary to create the
-#' cluster.
+#' of the function \link{getTunableArgs}. Hyperparameters not included in the
+#' `hypers` argument take the value that they have in the passed model.
 #'
-#' @return code{\linkS4class{SDMtune}} object.
+#' @return \linkS4class{SDMtune} object.
 #' @export
-#' @importFrom progress progress_bar
 #'
 #' @author Sergio Vignali
 #'
-#' @seealso \code{\link{randomSearch}} and \code{\link{optimizeModel}}.
+#' @seealso \link{randomSearch} and \link{optimizeModel}.
 #'
 #' @examples
 #' \donttest{
@@ -81,6 +73,11 @@
 gridSearch <- function(model, hypers, metric, test = NULL, env = NULL,
                        parallel = FALSE, save_models = TRUE) {
 
+  # TODO remove this code in a next release
+  if (parallel)
+    warning("parallel argument is deprecated and not used anymore",
+            call. = FALSE, immediate. = TRUE)
+
   metric <- match.arg(metric, choices = c("auc", "tss", "aicc"))
   # Create a grid with all the possible combination of hyperparameters
   grid <- .get_hypers_grid(model, hypers)
@@ -119,12 +116,11 @@ gridSearch <- function(model, hypers, metric, test = NULL, env = NULL,
   .show_chart(folder)
 
   # Loop through all the settings in grid
-  for (i in 1:nrow(grid)) {
+  for (i in seq_len(nrow(grid))) {
 
     obj <- .create_model_from_settings(model, settings = grid[i, ])
 
-    train_metric[i, ] <- list(i, .get_metric(metric, obj, env = env,
-                                             parallel = parallel))
+    train_metric[i, ] <- list(i, .get_metric(metric, obj, env = env))
     if (metric != "aicc")
       val_metric[i, ] <- list(i, .get_metric(metric, obj, test))
 
